@@ -389,7 +389,7 @@ def show_timetable(current_schedule):
 
     actual_surgery_proced = ['Procedure :'] + actual_surgery_proced
     actual_surgery_dates = ['Date :'] + actual_surgery_dates
-    actual_surgery_ot = ['OT :'] + actual_surgery_ot
+    actual_surgery_ot = ['Operating Theatre :'] + actual_surgery_ot
     actual_surgery_time = ['Time :'] + actual_surgery_time
     actual_surgery_durations = ['Duration :'] + actual_surgery_durations
 
@@ -407,7 +407,7 @@ def show_timetable(current_schedule):
         for j in range(5):
             # e = Label(canvas_frame, relief=GROOVE, width=20)
             # e.grid(row=i, column=j, sticky=NSEW)
-            e = Label(canvas_frame, relief=GROOVE)
+            e = Label(canvas_frame, relief=GROOVE, bg='white')
             e.place(relwidth=0.2, relx=j * 0.2, y=900 + i * 20)
             e.config(text='%s' % final_list[j][i])
             cols_list.append(e)
